# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './femtonics_mesc_template.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(639, 697)
        DockWidget.setFloating(True)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tabWidget = QtWidgets.QTabWidget(self.dockWidgetContents)
        self.tabWidget.setObjectName("tabWidget")
        self.tab_mesc_file = QtWidgets.QWidget()
        self.tab_mesc_file.setObjectName("tab_mesc_file")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.tab_mesc_file)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.pushButton_open_file = QtWidgets.QPushButton(self.tab_mesc_file)
        self.pushButton_open_file.setObjectName("pushButton_open_file")
        self.horizontalLayout.addWidget(self.pushButton_open_file)
        self.label_current_file_name = QtWidgets.QLabel(self.tab_mesc_file)
        self.label_current_file_name.setText("")
        self.label_current_file_name.setObjectName("label_current_file_name")
        self.horizontalLayout.addWidget(self.label_current_file_name)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.verticalLayout_5.addLayout(self.horizontalLayout)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.pushButton_close_file = QtWidgets.QPushButton(self.tab_mesc_file)
        self.pushButton_close_file.setObjectName("pushButton_close_file")
        self.horizontalLayout_4.addWidget(self.pushButton_close_file)
        spacerItem1 = QtWidgets.QSpacerItem(37, 33, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem1)
        self.verticalLayout_5.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.tab_mesc_file)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.listWidget_session = ListWidget(self.tab_mesc_file)
        self.listWidget_session.setObjectName("listWidget_session")
        self.verticalLayout.addWidget(self.listWidget_session)
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_2 = QtWidgets.QLabel(self.tab_mesc_file)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.verticalLayout_2.addWidget(self.label_2)
        self.listWidget_unit = ListWidget(self.tab_mesc_file)
        self.listWidget_unit.setObjectName("listWidget_unit")
        self.verticalLayout_2.addWidget(self.listWidget_unit)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.label_3 = QtWidgets.QLabel(self.tab_mesc_file)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_3.addWidget(self.label_3)
        self.listWidget_channel = ListWidget(self.tab_mesc_file)
        self.listWidget_channel.setObjectName("listWidget_channel")
        self.verticalLayout_3.addWidget(self.listWidget_channel)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        self.verticalLayout_5.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_5 = QtWidgets.QLabel(self.tab_mesc_file)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_5.addWidget(self.label_5)
        self.lineEdit_comment = QtWidgets.QLineEdit(self.tab_mesc_file)
        self.lineEdit_comment.setReadOnly(True)
        self.lineEdit_comment.setObjectName("lineEdit_comment")
        self.horizontalLayout_5.addWidget(self.lineEdit_comment)
        self.verticalLayout_5.addLayout(self.horizontalLayout_5)
        self.label_4 = QtWidgets.QLabel(self.tab_mesc_file)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.verticalLayout_5.addWidget(self.label_4)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.pushButton_import_image = QtWidgets.QPushButton(self.tab_mesc_file)
        self.pushButton_import_image.setObjectName("pushButton_import_image")
        self.horizontalLayout_3.addWidget(self.pushButton_import_image)
        self.pushButton_import_stim_map = QtWidgets.QPushButton(self.tab_mesc_file)
        self.pushButton_import_stim_map.setObjectName("pushButton_import_stim_map")
        self.horizontalLayout_3.addWidget(self.pushButton_import_stim_map)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.tabWidget.addTab(self.tab_mesc_file, "")
        self.tab_stimulus_mapping = QtWidgets.QWidget()
        self.tab_stimulus_mapping.setObjectName("tab_stimulus_mapping")
        self.tabWidget.addTab(self.tab_stimulus_mapping, "")
        self.verticalLayout_4.addWidget(self.tabWidget)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)
        DockWidget.setTabOrder(self.tabWidget, self.pushButton_open_file)
        DockWidget.setTabOrder(self.pushButton_open_file, self.pushButton_close_file)
        DockWidget.setTabOrder(self.pushButton_close_file, self.listWidget_session)
        DockWidget.setTabOrder(self.listWidget_session, self.listWidget_unit)
        DockWidget.setTabOrder(self.listWidget_unit, self.listWidget_channel)
        DockWidget.setTabOrder(self.listWidget_channel, self.lineEdit_comment)
        DockWidget.setTabOrder(self.lineEdit_comment, self.pushButton_import_image)
        DockWidget.setTabOrder(self.pushButton_import_image, self.pushButton_import_stim_map)

    def retranslateUi(self, DockWidget):
        _translate = QtCore.QCoreApplication.translate
        DockWidget.setWindowTitle(_translate("DockWidget", "Doc&kWidget"))
        self.pushButton_open_file.setText(_translate("DockWidget", "Open .mesc file"))
        self.pushButton_close_file.setToolTip(_translate("DockWidget", "Close the file handle, allows the file to be accessible by other programs"))
        self.pushButton_close_file.setText(_translate("DockWidget", "Close file"))
        self.label.setText(_translate("DockWidget", "Session"))
        self.label_2.setText(_translate("DockWidget", "Unit"))
        self.label_3.setText(_translate("DockWidget", "Channel"))
        self.label_5.setText(_translate("DockWidget", "Comment:"))
        self.lineEdit_comment.setToolTip(_translate("DockWidget", "Comment stored in the selected MUnit"))
        self.label_4.setText(_translate("DockWidget", "Import:"))
        self.pushButton_import_image.setText(_translate("DockWidget", "Image"))
        self.pushButton_import_stim_map.setText(_translate("DockWidget", "Stim Map"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_mesc_file), _translate("DockWidget", "MESc File"))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_stimulus_mapping), _translate("DockWidget", "Stimulus Mapping"))

from ....pyqtgraphCore.widgets.ListWidget import ListWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ImageViewTemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(888, 742)
        self.gridLayout_10 = QtWidgets.QGridLayout(Form)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.splitterHighest = QtWidgets.QSplitter(Form)
        self.splitterHighest.setOrientation(QtCore.Qt.Vertical)
        self.splitterHighest.setObjectName("splitterHighest")
        self.splitterFilesImage = QtWidgets.QSplitter(self.splitterHighest)
        self.splitterFilesImage.setOrientation(QtCore.Qt.Vertical)
        self.splitterFilesImage.setObjectName("splitterFilesImage")
        self.splitter = QtWidgets.QSplitter(self.splitterFilesImage)
        self.splitter.setOrientation(QtCore.Qt.Vertical)
        self.splitter.setObjectName("splitter")
        self.layoutWidget = QtWidgets.QWidget(self.splitter)
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout_8.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.btnExportWorkEnv = QtWidgets.QPushButton(self.layoutWidget)
        self.btnExportWorkEnv.setObjectName("btnExportWorkEnv")
        self.gridLayout_8.addWidget(self.btnExportWorkEnv, 1, 5, 1, 1)
        self.histogram = HistogramLUTWidget(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.histogram.sizePolicy().hasHeightForWidth())
        self.histogram.setSizePolicy(sizePolicy)
        self.histogram.setMinimumSize(QtCore.QSize(150, 0))
        self.histogram.setMaximumSize(QtCore.QSize(150, 16777215))
        self.histogram.setObjectName("histogram")
        self.gridLayout_8.addWidget(self.histogram, 2, 5, 2, 1)
        self.graphicsView = GraphicsView(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.graphicsView.sizePolicy().hasHeightForWidth())
        self.graphicsView.setSizePolicy(sizePolicy)
        self.graphicsView.setObjectName("graphicsView")
        self.gridLayout_8.addWidget(self.graphicsView, 1, 1, 4, 4)
        self.label_curr_img_seq_name = QtWidgets.QLabel(self.layoutWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.label_curr_img_seq_name.setFont(font)
        self.label_curr_img_seq_name.setText("")
        self.label_curr_img_seq_name.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.label_curr_img_seq_name.setObjectName("label_curr_img_seq_name")
        self.gridLayout_8.addWidget(self.label_curr_img_seq_name, 0, 2, 1, 1)
        self.label = QtWidgets.QLabel(self.layoutWidget)
        font = QtGui.QFont()
        font.setPointSize(14)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByKeyboard|QtCore.Qt.TextSelectableByMouse)
        self.label.setObjectName("label")
        self.gridLayout_8.addWidget(self.label, 0, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_8.addItem(spacerItem, 0, 3, 1, 1)
        self.groupBoxZLevel = QtWidgets.QGroupBox(self.layoutWidget)
        self.groupBoxZLevel.setAlignment(QtCore.Qt.AlignCenter)
        self.groupBoxZLevel.setObjectName("groupBoxZLevel")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBoxZLevel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.spinBoxZLevel = QtWidgets.QSpinBox(self.groupBoxZLevel)
        self.spinBoxZLevel.setObjectName("spinBoxZLevel")
        self.verticalLayout.addWidget(self.spinBoxZLevel)
        self.verticalSliderZLevel = QtWidgets.QSlider(self.groupBoxZLevel)
        self.verticalSliderZLevel.setMinimumSize(QtCore.QSize(25, 0))
        self.verticalSliderZLevel.setAutoFillBackground(False)
        self.verticalSliderZLevel.setPageStep(5)
        self.verticalSliderZLevel.setOrientation(QtCore.Qt.Vertical)
        self.verticalSliderZLevel.setInvertedAppearance(True)
        self.verticalSliderZLevel.setInvertedControls(True)
        self.verticalSliderZLevel.setTickPosition(QtWidgets.QSlider.TicksBelow)
        self.verticalSliderZLevel.setTickInterval(5)
        self.verticalSliderZLevel.setObjectName("verticalSliderZLevel")
        self.verticalLayout.addWidget(self.verticalSliderZLevel)
        self.gridLayout_8.addWidget(self.groupBoxZLevel, 1, 0, 3, 1)
        self.roiPlot = PlotWidget(self.splitter)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.roiPlot.sizePolicy().hasHeightForWidth())
        self.roiPlot.setSizePolicy(sizePolicy)
        self.roiPlot.setMinimumSize(QtCore.QSize(0, 40))
        self.roiPlot.setObjectName("roiPlot")
        self.gridLayout_10.addWidget(self.splitterHighest, 0, 0, 1, 1)

        self.retranslateUi(Form)
        self.verticalSliderZLevel.valueChanged['int'].connect(self.spinBoxZLevel.setValue)
        self.spinBoxZLevel.valueChanged['int'].connect(self.verticalSliderZLevel.setValue)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.graphicsView, self.btnExportWorkEnv)
        Form.setTabOrder(self.btnExportWorkEnv, self.histogram)
        Form.setTabOrder(self.histogram, self.spinBoxZLevel)
        Form.setTabOrder(self.spinBoxZLevel, self.verticalSliderZLevel)
        Form.setTabOrder(self.verticalSliderZLevel, self.roiPlot)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.btnExportWorkEnv.setText(_translate("Form", "Export Video"))
        self.label.setText(_translate("Form", "Current image sequence:"))
        self.groupBoxZLevel.setTitle(_translate("Form", "z-level"))
        self.verticalSliderZLevel.setToolTip(_translate("Form", "move along the z-axis"))

from ..widgets.GraphicsView import GraphicsView
from ..widgets.HistogramLUTWidget import HistogramLUTWidget
from ..widgets.PlotWidget import PlotWidget



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: kushal

Chatzigeorgiou Group
Sars International Centre for Marine Molecular Biology

GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007

A module that is globally accessible from all modules.
"""

import numpy as np
import os
from psutil import cpu_count
import json
from configparser import RawConfigParser
from warnings import warn

#################################################################

# System Configuration

#################################################################

if os.name == 'nt':
    IS_WINDOWS = True
    HOME = 'USERPROFILE'
else:
    IS_WINDOWS = False
    HOME = 'HOME'

try:
    import caiman
except ImportError:
    warn(
        "Caiman package not found. "
        "Caiman features will be disabled."
    )
    HAS_CAIMAN = False
else:
    HAS_CAIMAN = True

# try:
#     print("Importing ISX")
#     import isx
#     print("Imported ISX")
# except ImportError:
#     warn("Inscopix API not found, Inscopix importer will be disabled")
#     HAS_ISX = False
# else:
#     HAS_ISX = True

try:
    import tensorflow
except ImportError:
    warn(
        "tensorflow not found. Nuset segmentation will be disabled"
    )
    HAS_TENSORFLOW = False
else:
    HAS_TENSORFLOW = True

try:
    import tslearn
except ImportError:
    warn(
        "tslearn package not found. "
        "tslearn features will be disabled."
    )
    HAS_TSLEARN = False
else:
    HAS_TSLEARN = True

sys_cfg = {}

num_types = [int, float, np.int64, np.float64]

sys_cfg_dir: str = os.path.join(os.environ[HOME], '.mesmerize')

sys_cfg_file: str = os.path.join(sys_cfg_dir, 'config.json')

console_history_path = os.path.join(sys_cfg_dir, 'console_history')
if not os.path.isdir(console_history_path):
    os.makedirs(console_history_path)

_prefix_comments = \
    [
        '# For example if you are running in an anaconda environment',
        '# export PATH="/home/<user>/anaconda3:$PATH"',
        '# source activate my_environment',
        '# Or if you are using a python virtual environment',
        '# source /<path_to_env>/activate',
        '# Adjust these according to your hardware'
    ]

if IS_WINDOWS:
    _prefix_commands = \
        [
            "# If using anaconda, you may need a command to activate the conda environment.",
            "# If this is the case, uncomment the following line.",
            "# conda activate mesmerize",
            "\n"
        ]

else:
    _prefix_commands = _prefix_comments + ["export MKL_NUM_THREADS=1",
                                           "export OPENBLAS_NUM_THREADS=1", '\n']

default_sys_config = {'_MESMERIZE_N_THREADS': cpu_count() - 1,
                      '_MESMERIZE_USE_CUDA': False,
                      '_MESMERIZE_PYTHON_CALL': 'python3',
                      '_MESMERIZE_PREFIX_COMMANDS': '\n'.join(_prefix_commands),
                      '_MESMERIZE_CUSTOM_MODULES_DIR': os.environ[HOME] + '/mesmerize_custom_modules',
                      '_MESMERIZE_WORKDIR': '',
                      'recent_projects': []
                      }

if IS_WINDOWS:
    default_sys_config.update({'_MESMERIZE_PYTHON_CALL': 'python'})


# patching in something that will probably be used in mesmerize v1.0 to simplify sys config things
class ENVIRONMENT:
    def __init__(self):
        self.LRU_CACHE_MAXSIZE: int = 64  # `maxsize` argument for @lru_cache


# update the default env vars with any that are specified in the env
def get_environment() -> ENVIRONMENT:
    e = ENVIRONMENT()
    for opt, val in e.__dict__.items():
        # user can prefix the env vars with "MESMERIZE" if they want, but not necessary
        if (opt in os.environ.keys()) or (f'MESMERIZE_{opt}' in os.environ.keys()):
            setattr(e, opt, type(val)(os.environ[opt]))  # to convert str to other types, like str -> int/float

    return e


class SysConfig:
    def __init__(self, n_threads: int,
                 use_cuda: bool,
                 python_call: str,
                 prefix_commands: str,
                 custom_modules_dir: str,
                 workdir: str,
                 recent_projects: list):
        self.n_threads = n_threads
        self.use_cuda = use_cuda
        self.python_call = python_call
        self.prefix_commands = prefix_commands
        self.custom_modules_dir = custom_modules_dir
        self.workdir = workdir
        self.recent_projects = recent_projects


def create_new_sys_config() -> dict:
    if not os.path.isdir(sys_cfg_dir):
        os.makedirs(sys_cfg_dir)

    save_sys_config(default_sys_config)

    return default_sys_config


def get_sys_config() -> dict:
    """Get the user-set system configuration"""

    if not os.path.isfile(sys_cfg_file):
        return create_new_sys_config()

    with open(sys_cfg_file, 'r') as f:
        sys_cfg = json.load(f)

    return sys_cfg


def save_sys_config(cfg: dict):
    if not set(cfg.keys()).issubset(default_sys_config.keys()):
        raise KeyError('Required config fields are missing. The following fields must be present:\n' + str(cfg.keys()))

    if not cfg['_MESMERIZE_PREFIX_COMMANDS'].endswith('\n'):
        cfg['_MESMERIZE_PREFIX_COMMANDS'] += '\n'

    with open(sys_cfg_file, 'w') as f:
        json.dump(cfg, f, indent=4)


#################################################################

# Project Configuration

#################################################################

proj_path = None
proj_cfg = RawConfigParser(allow_no_value=True)
proj_cfg['ROI_DEFS'] = {}
proj_cfg['STIM_DEFS'] = {}

proj_cfg.optionxform = str
special = {}
df_refs = {}


def save_proj_config():
    set_proj_special()
    with open(proj_path + '/config.cfg', 'w') as configfile:
        proj_cfg.write(configfile)


def create_new_proj_config():
    defaultInclude = ['SampleID', 'date', 'comments']
    proj_cfg['INCLUDE'] = dict.fromkeys(defaultInclude)

    defaultExclude = ['ImgInfoPath', 'ImgPath', 'ImgUUID', 'ROI_State', 'uuid_curve', 'misc', 'AnimalID']
    proj_cfg['EXCLUDE'] = dict.fromkeys(defaultExclude)

    proj_cfg['ROI_DEFS'] = {}

    proj_cfg['STIM_DEFS'] = {}

    proj_cfg['ALL_STIMS'] = {}

    proj_cfg['CUSTOM_COLUMNS'] = {}

    proj_cfg['CHILD_DFS'] = {}

    set_proj_special()

    save_proj_config()


def open_proj_config():
    proj_cfg.read(proj_path + '/config.cfg')
    set_proj_special()


def set_proj_special():
    special['Timings'] = proj_cfg.options('STIM_DEFS')



import cv2
import numpy as np
from .common import BitDepthConverter
from typing import Tuple, Union, Any, List


def get_rect(seq: np.ndarray,
              projection: str,
              method: str,
              denoise: str = 'blur',
              denoise_params: tuple = (16, 16),
              thresh: tuple = (50, 255),
              padding: int = 30) -> Tuple[bool, List[Tuple[Union[object, Any], Union[object, Any]]]]:
    """

    :param seq:             image sequence
    :param projection:      'max', 'std', or 'max+std'
    :param method:          'threshold', 'spectral_saliency', or 'fine_grained_saliency'
    :param denoise:         'blur', 'NlMeans', or 'none'
    :param denoise_params:  params passed to cv2.blur or cv2.fastNlMeansDenoising
    :param thresh:          thresholds for binary image from which to get contours and rect
    :param padding:         number of pixels by which to increase boundaries of returned rectangle
    :return:                [(x1, y1), (x2, y2)]
    """

    if projection == 'max':
        img = seq.max(axis=2)
    elif projection == 'std':
        img = seq.std(axis=2)
    elif projection == 'max+std':
        img = seq.max(axis=2) + seq.std(axis=2)
    else:
        raise ValueError('Invalid projection argument: ' + str(projection))

    if img.dtype != np.uint8:
        img = img.astype('uint16')
        min_img = img.min()
        max_img = img.max()
        lut = BitDepthConverter.create_LUT((int(min_img), int(max_img)), 16, 8)
        img = BitDepthConverter.apply_LUT(img, lut)

    if denoise == 'blur':
        img = cv2.blur(img, denoise_params)
    elif denoise == 'NlMeans':
        img = cv2.fastNlMeansDenoising(img, None, *denoise_params)
    elif denoise == 'none':
        pass
    else:
        raise ValueError('Invalid denoise argument: ' + str(denoise))

    if method == 'spectral_saliency':
        saliency = cv2.saliency.StaticSaliencySpectralResidual_create()
        (ret, saliencyMap) = saliency.computeSaliency(img)
        img = (saliencyMap * 255).astype("uint8")

    elif method == 'fine_grained_saliency':
        saliency = cv2.saliency.StaticSaliencyFineGrained_create()
        (success, saliencyMap) = saliency.computeSaliency(img)

    rval, th_img = cv2.threshold(img.astype('uint8'), *thresh, cv2.THRESH_BINARY + cv2.THRESH_OTSU)

    im2, contours, hierarchy = cv2.findContours(th_img, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)

    try:
        hierarchy = hierarchy[0]
    except:
        hierarchy = []

    height, width = th_img.shape
    min_x, min_y = width, height
    max_x = max_y = 0

    # computes the bounding box for the contour, and draws it on the frame,
    for contour, hier in zip(contours, hierarchy):
        (x, y, w, h) = cv2.boundingRect(contour)
        min_x, max_x = min(x, min_x), max(x + w, max_x)
        min_y, max_y = min(y, min_y), max(y + h, max_y)
        # if w > 80 and h > 80:
        # cv2.rectangle(th_img, (x,y), (x+w,y+h), (255, 0, 0), 2)

    x1 = max(0, min_x - padding)
    x2 = min(img.shape[0], max_x + padding)

    y1 = max(0, min_y - padding)
    y2 = min(img.shape[1], max_y + padding)

    if max_x - min_x > 0 and max_y - min_y > 0:

        return True, [(x1, y1), (x2, y2)]

    else:
        return False, [(x1, y1), (x2, y2)]


def crop(seq: np.ndarray, params: dict) -> np.ndarray:
    """
    :param seq:     image sequence
    :param params:  params, passed to get_rect()
    :return:        cropped image sequence
    """
    r, rect = get_rect(seq, **params)
    if r is False:
        raise ValueError('Cannot crop image sequence, try different parameters\n' + str(rect))

    x1 = rect[0][0]
    y1 = rect[0][1]

    x2 = rect[1][0]
    y2 = rect[1][1]

    return seq[y1:y2, x1:x2, :]



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: kushal

Chatzigeorgiou Group
Sars International Centre for Marine Molecular Biology

GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
"""

from ...common.qdialogs import *
from ...common.configuration import proj_cfg
from ..core.common import ViewerUtils
from ..core.viewer_work_environment import ViewerWorkEnv
from .pytemplates.suite2p_pytemplate import *
import numpy as np
from pathlib import Path
from scipy.spatial import cKDTree
from .roi_manager_modules.managers import ManagerScatterROI
from tqdm import tqdm
from typing import *
import logging


logger = logging.getLogger()


class Suite2pData:
    attrs = ['F', 'Fneu', 'Fneu_sub', 'stat', 'ops', 'iscell']

    def __init__(self):
        self.path = None
        self.F = None
        self.Fneu = None
        self.stat = None
        self.ops = None
        self.iscell = None

        self.use_iscell = True
        self.Fneu_sub = None

    def set_dir(self, path: Union[Path, str]):
        self.clear()
        self.path = Path(path)

        for f in ['F', 'Fneu', 'stat', 'ops', 'iscell']:
            f_path = self.path.joinpath(f"{f}.npy")

            logger.info(f'checking: {f_path}')

            if not f_path.is_file():
                raise FileNotFoundError(f"The selected directory does not have the '{f}.npy' file.")

            setattr(self, f, np.load(f_path, allow_pickle=True))

    def clear(self):
        for attr in self.attrs:
            delattr(self, attr)
            setattr(self, attr, None)


def get_vertices(s: np.ndarray):
    """
    Uses the stat array that contains a collection of all points contained by the ROI
    and uses a k-neighbors tree to only keep the edge points of the ROI
    """
    xs = s['xpix']
    ys = s['ypix']

    points = np.array((xs, ys)).T

    kdt = cKDTree(points)
    vertices = []

    for p in points:
        if len(kdt.query_ball_point(p, 1)) < 5:
            vertices.append(p)

    vs = np.vstack(vertices)

    return vs


class ModuleGUI(QtWidgets.QDockWidget):
    def __init__(self, parent, viewer_reference):
        self.vi = ViewerUtils(viewer_reference)
        QtWidgets.QDockWidget.__init__(self, parent)

        self.ui = Ui_DockWidgetSuite2p()
        self.ui.setupUi(self)

        self.ui.pushButton_dir.clicked.connect(self.select_dir)
        self.ui.pushButton_import.clicked.connect(self.import_rois)

        self.data = Suite2pData()

    @present_exceptions('Invalid dir', '')
    @use_open_dir_dialog('Select dir containing Suite2p output')
    def select_dir(self, path, *args):
        self.ui.label_dir.setText('<not selected>')

        self.vi.viewer.status_bar_label.showMessage('Checking Suite2p output data, please wait...')
        self.data.set_dir(path)
        self.vi.viewer.status_bar_label.showMessage('Finished checking Suite2p output data.')

        self.data.Fneu_sub = (self.ui.spinBox_Fneu_sub.value() / 100)

        self.ui.label_dir.setText(path)

    def import_rois(self):
        if 's2p_iscell' not in proj_cfg.options('ROI_DEFS'):
            QMessageBox.warning(self, 'Missing `s2p_iscell` column',
                                'You have not created an `s2p_iscell` ROI Type column in your project configuration, '
                                'so you will not see the probabilities from the Suite2p classifier.')

            self.has_iscell_column = False
        else:
            self.has_iscell_column = True

        if (len(self.data.stat) > 100) and (not self.ui.checkBox_use_iscell.isChecked()):
            if QMessageBox.warning(self, 'Large Import Warning!',
                                      f'This will import {len(self.data.stat)} ROIs which may take a few minutes.\n'
                                      f'You may want to consider importing only ROIs classified as cells '
                                      f'by the suite2p classifier.\n\n'
                                      f'Continue anyways?', QMessageBox.Yes, QMessageBox.No) == QMessageBox.No:
                return

        if len(self.vi.viewer.workEnv.roi_manager.roi_list) > 0:
            if QMessageBox.warning(self, 'Clear ROI Manager?',
                                             'Importing Suite2p ROIs will clear the ROI Manager, proceed anyway?',
                                             QMessageBox.Yes, QMessageBox.No) \
                    == QMessageBox.No:
                return

        # get the GUI ROI Manager module and set it in manual mode
        self.vi.viewer.parent().get_module('roi_manager').start_backend('ScatterROI')

        # get the backend ROI manager
        roi_manager = self.vi.viewer.workEnv.roi_manager
        assert isinstance(roi_manager, ManagerScatterROI)

        # the data
        F = self.data.F
        Fneu = self.data.Fneu
        stat = self.data.stat
        iscell = self.data.iscell

        # if import only ROIs which Suite2p classified as cells
        if self.ui.checkBox_use_iscell.isChecked():
            mask = self.data.iscell[:, 0] == 1

            F = F[mask]
            Fneu = Fneu[mask]
            stat = stat[mask]
            iscell = iscell[mask]

        # substract neuropil contribution
        Fc = F - (self.data.Fneu_sub * Fneu)

        for ix in tqdm(range(len(stat))):
            self.vi.viewer.status_bar_label.showMessage(f'Importing ROIs from Suite2p output data. {ix} / {len(stat)}')

            pos = get_vertices(stat[ix])
            xs = pos[:, 0]
            ys = pos[:, 1]

            y = Fc[ix]

            roi = roi_manager.add_roi(
                curve=y,
                xs=xs,
                ys=ys,
                metadata=stat[ix]
            )

            # x = np.arange(y.size + 1, dtype=np.float64)[1:]
            #
            # # set curve data
            # roi.curve_data = (x, y)


            # set is_cell data
            if self.has_iscell_column:
                roi.set_tag('s2p_iscell', f"{int(iscell[ix][0])} | {iscell[ix][1]}")

        log = {'Fneu_subtraction': self.data.Fneu_sub,
               'ops': self.data.ops}

        self.vi.viewer.workEnv.history_trace.append({'suite_2p_import': log})

        self.vi.viewer.status_bar_label.showMessage('Finished importing ROIs from Suite2p output data!')



import numpy as np
import numexpr
from tqdm import tqdm
from ...plotting.utils import auto_colormap
from ..core import ViewerUtils
from ...common.qdialogs import *
import os
import skvideo.io
from .pytemplates.exporter_pytemplate import *
import logging


logger = logging.getLogger()


# adapted from https://github.com/ver228/tierpsy-tracker/blob/master/tierpsy/analysis/compress/compressVideo.py
def normalize_image(img, imin, imax):
    factor = 255 / (imax - imin)

    imgN = numexpr.evaluate('(img-imin)*factor')
    imgN = imgN.astype(np.uint8)
    imgN[imgN == 255] = 254

    return imgN


class ModuleGUI(QtWidgets.QWidget):
    def __init__(self, parent, viewer_ref: ViewerUtils):
        QtWidgets.QWidget.__init__(self)
        self.viewer = viewer_ref

        self.ui = Ui_exporter_template()
        self.ui.setupUi(self)

        self.ui.sliderFPS_Scaling.valueChanged.connect(
            lambda v: self.ui.doubleSpinBox.setValue(v / 10)
        )

        self.ui.btnExport.clicked.connect(lambda: self.export())
        self.ui.listWidget.set_cmap('gnuplot2')
        self.ui.btnChoosePath.clicked.connect(
            lambda: self.set_path()
        )

        self.ui.lineEdPath.setToolTip(
            "Do not specify the extension, it is "
            "chosen automatically based on the codec"
        )

    @use_save_file_dialog('Choose path, DO NOT SPECIFY EXTENSION')
    def set_path(self, path, *args):
        if os.path.isfile(path):
            raise FileExistsError

        else:
            self.ui.lineEdPath.setText(path)

    @present_exceptions('Export Error')
    def export(self):
        if (self.viewer.workEnv.imgdata is None) or (self.viewer.workEnv.imgdata.seq is None):
            raise ValueError("No image data to export")

        codec = self.ui.comboBoxFormat.currentText()

        if codec in ['libx264']:
            extn = 'avi'
        elif codec in ['wmv2']:
            extn = 'wmv'

        fps_scaling = self.ui.doubleSpinBox.value()

        if self.ui.radioAuto.isChecked():
            vmin = np.nanmin(self.viewer.workEnv.imgdata.seq)
            vmax = np.nanmax(self.viewer.workEnv.imgdata.seq)

        else:
            vmin = self.viewer.levelMin
            vmax = self.viewer.levelMax

        cmap = self.ui.listWidget.get_cmap()

        path = self.ui.lineEdPath.text()
        if os.path.isfile(path):
            raise FileExistsError

        seq = self.viewer.workEnv.imgdata.seq

        logger.info('Normalizing image for 8bit video output')
        norm = normalize_image(seq, vmin, vmax)

        # RGB LUT
        lut = np.zeros(shape=(256, 1, 3), dtype=np.uint8)

        cmap = np.vstack(auto_colormap(n_colors=256, cmap=cmap))

        lut[:, 0, :] = cmap[:, :-1] * 255

        orig_fps = self.viewer.workEnv.imgdata.meta['fps']

        r = int(orig_fps * fps_scaling)

        pts = orig_fps / float(r)

        output_params = \
            {
                '-r': str(r),
                '-filter:v': f"setpts={pts}*PTS",
                '-vcodec': codec
            }
        logger.info("Creating ffmpeg writer")
        writer = skvideo.io.FFmpegWriter(f'{path}.{extn}', outputdict=output_params)

        logger.info("Writing video")
        for i in tqdm(range(norm.shape[2])):
            frame = norm[:, :, i]
            # use the LUT to create RGB pseudocolored image
            writer.writeFrame(lut[frame][:, :, 0, :])
        writer.close()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'beeswarm_plots_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_beeswarm_plots_template(object):
    def setupUi(self, beeswarm_plots_template):
        beeswarm_plots_template.setObjectName("beeswarm_plots_template")
        beeswarm_plots_template.resize(400, 300)
        self.gridLayout = QtWidgets.QGridLayout(beeswarm_plots_template)
        self.gridLayout.setObjectName("gridLayout")
        self.graphicsView = GraphicsLayoutWidget(beeswarm_plots_template)
        self.graphicsView.setObjectName("graphicsView")
        self.gridLayout.addWidget(self.graphicsView, 0, 0, 1, 1)

        self.retranslateUi(beeswarm_plots_template)
        QtCore.QMetaObject.connectSlotsByName(beeswarm_plots_template)

    def retranslateUi(self, beeswarm_plots_template):
        _translate = QtCore.QCoreApplication.translate
        beeswarm_plots_template.setWindowTitle(_translate("beeswarm_plots_template", "Form"))

from pyqtgraphCore import GraphicsLayoutWidget



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on May 13 2018

@author: kushal

Chatzigeorgiou Group
Sars International Centre for Marine Molecular Biology

GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007
"""

# Functions for organizing your meta data into a format
# that for Mesmerize to use.
#
# You may define your own function to organize your meta data.
# It MUST return a dict which has at least the following keys:
# `origin`, `fps` and `date`.
#
# The `origin` is a string describing the software or microscope
# the recording comes from. This is for your own record.
# The `fps` is the sampling rate of the recording.
# The `date` is the date & time represented by a string in the
# following format: "YYYYMMDD_HHMMSS"
#
# In addition to these 3 keys, you may include any additional
# information as you wish.
#
# Example:
#
# d = \
# {
#     'origin': "microscope or software origin",
#     'fps':     10.0,
#     'date':    "20201123_172345"
# }
#
# Example function:
#
# def MyMetaOrganizer(path: str) -> dict:
#     """.ext""" # define the file ext in the docstring for it to be automatically recognized in the tiff file GUI
#     raw_meta = function_to_load_my_file(path)
#
#     # do stuff to organize the raw_meta
#
#     meta = ... # stuff to organize raw meta
#
#     # return the organized meta data dict
#     # that mesmerize can use
#
#     return meta
#

import json
import tifffile
from datetime import datetime
import numpy as np
from PyQt5 import QtWidgets
from warnings import warn
from mesmerize.common import is_app

try:
    import xmltodict
except ImportError:
    HAS_XMLTODICT = False
else:
    HAS_XMLTODICT = True


def AwesomeImager(path: str) -> dict:
    """.json"""
    meta = json.load(open(path, 'r'))

    meta_d = \
        {
            'origin': 'AwesomeImager',
            'version': meta['version'],
            'fps': meta['framerate'],
            'date': meta['date'] + '_' + meta['time'],
            'vmin': meta['level_min'],
            'vmax': meta['level_max'],
            'orig_meta': meta  # just the entire original meta data dict
        }
    return meta_d


def json_minimal(path: str) -> dict:
    """.json"""
    meta = json.load(open(path, 'r'))

    required = ['fps', 'date']

    if not all(k in meta.keys() for k in required):
        raise KeyError(f'Meta data dict must contain all mandatory fields: {required}')

    meta_d = \
        {
            'origin': meta['origin'],
            'fps': meta['fps'],
            'date': meta['date'],
            'orig_meta': meta
        }

    return meta_d


def ome_tiff(path: str) -> dict:
    """.tiff"""

    if not HAS_XMLTODICT:
        raise ImportError("`xmltodict` must be installed to use ome_tiff meta data")

    tif = tifffile.TiffFile(path)

    if tif.ome_metadata is None:
        raise ValueError("OME XML meta data is not present in the given tiff file")

    # convert it from the garbled OME XML to a dict for normal humans
    ome_meta = xmltodict.parse(tif.ome_metadata)

    # get date in YYYYMMDD_HHMMSS format
    date = datetime.strptime(
        ome_meta['OME']['OME:Image']['OME:AcquisitionDate'],
        "%Y-%m-%dT%H:%M:%SZ"
    ).strftime("%Y%m%d_%H%M%S")

    # list pertaining to image meta data
    ome_img_meta = ome_meta['OME']['OME:Image']['OME:Pixels']['OME:Plane']

    # number of zplanes and number of timepoints
    # if n_zplanes > 1, then n_timepoints is the number of acquired volumes
    n_zplanes = int(ome_meta['OME']['OME:Image']['OME:Pixels']['@SizeZ'])
    n_timepoints = int(ome_meta['OME']['OME:Image']['OME:Pixels']['@SizeT'])

    # an array that will contain all the time deltas
    # use it to get the mean `sampling_rate`, as well as the standard deviation
    # and max deviation from the mean frame rate
    a = np.zeros(shape=(n_zplanes, n_timepoints), dtype=np.float64)

    for n_zplane in range(n_zplanes):
        a[n_zplane, :] = [float(f['@DeltaT']) for f in ome_img_meta if int(f['@TheZ']) == n_zplane]

    sampling_rates = (1 / np.diff(a))

    mean_sampling_rate = sampling_rates.mean()  # mean sampling rate
    std_sampling_rate = sampling_rates.std()  # standard deviation
    max_dev_sampling_rate = sampling_rates.ptp()  # max deviation from mean sampling rate

    if (max_dev_sampling_rate > 0.1) or (std_sampling_rate > 0.01):
        warning_msg = \
            f'This is a warning that the standard deviation or max deviation from the mean sampling rate might be ' \
            f'unusually high' \
            f'\n\n' \
            f'mean sampling rate: {mean_sampling_rate:.5f} Hz\n' \
            f'standard deviation of sampling rate: {std_sampling_rate:.5f} Hz\n' \
            f'maximum deviation from mean sampling rate: {max_dev_sampling_rate:.5f} Hz\n\n' \
            f'This message is shown when the max deviation is > 0.1 Hz or the standard deviation is > 0.01 Hz' \

        if QtWidgets.QApplication.instance() is not None:
            QtWidgets.QMessageBox.warning(
                None,
                'Sampling Rate Warning',
                warning_msg
            )
        else:
            warn(
                warning_msg
            )

    meta_d = \
        {
            'origin': 'ome_tiff',
            'fps': mean_sampling_rate,
            'fps_std': std_sampling_rate,
            'fps_max_dev': max_dev_sampling_rate,
            'date': date,
            'orig_meta': ome_meta
        }

    return meta_d


def ome_tif(path: str) -> dict:
    """.tif"""
    return ome_tiff(path)


def ome_btf(path: str) -> dict:
    """.btf"""
    return ome_tiff(path)


def inscopix(path: str) -> dict:
    """.json"""
    meta = json.load(open(path, 'r'))

    d = \
        {
            'fps': 1000 / meta['Exposure Time (ms)'],
            'origin': meta['Microscope Type'],
            'date': "00000000_000000",
            'orig_meta': meta,
        }

    return d



# -*- coding: utf-8 -*-
from ....analysis.math.tvregdiff import tv_reg_diff
from .common import *
from ....analysis.data_types import Transmission
from scipy.stats import zscore as _zscore, linregress
import pandas as pd


class AbsoluteValue(CtrlNode):
    """Performs numpy.abs(<input>). Returns root-mean-square value if <input> is complex"""
    nodeName = 'AbsoluteValue'
    uiTemplate = [('data_column', 'combo', {}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True})]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()
        if self.ctrls['Apply'].isChecked() is False:
            return

        output_column = '_ABSOLUTE_VALUE'

        self.t = transmission.copy()

        self.t.df[output_column] = self.t.df[self.data_column].apply(lambda x: np.abs(x))

        params = {'data_column': self.data_column,
                  'units': self.t.last_unit
                  }

        self.t.history_trace.add_operation(data_block_id='all', operation='absolute_value', parameters=params)
        self.t.last_output = output_column

        return self.t


class XpowerY(CtrlNode):
    """Raise each element of arrays in data column to the exponent Y"""
    nodeName = 'XpowerY'
    # Not sure why someone would take the 99th power, but I'll leave it there
    uiTemplate = [('data_column', 'combo', {}),
                  ('Y', 'doubleSpin', {'value': 2.0, 'min': -99.0, 'max': 99.0, 'step': 0.5}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True})]
    output_column = '_X_POWER_Y'

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()
        if self.ctrls['Apply'].isChecked() is False:
            return

        self.t = transmission.copy()
        Y = self.ctrls['Y'].value()
        params = {'data_column': self.data_column,
                  'exponent':    Y}

        self.t.df[self.output_column] = self.t.df[self.data_column].apply(lambda x: np.power(x, Y))

        self.t.history_trace.add_operation(data_block_id='all', operation='x_power_y', parameters=params)
        self.t.last_output = self.output_column

        return self.t


class LogTransform(CtrlNode):
    """Can perform various log transforms"""
    nodeName = 'LogTransform'
    uiTemplate = [('data_column', 'combo', {}),
                  ('transform', 'combo', {'values': ['log10', 'ln', 'modlog10', 'modln']}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True})]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()
        if self.ctrls['Apply'].isChecked() is False:
            return

        self.t = transmission.copy()

        output_column = '_LOG_TRANSFORM'

        transform = self.ctrls['transform'].currentText()
        params = {'data_column': self.data_column,
                  'transform': transform,
                  'units': self.t.last_unit}

        if transform == 'log10':
            self.t.df[output_column] = self.t.df[self.data_column].apply(lambda x: np.log10(x))

        elif transform == 'ln':
            self.t.df[output_column] = self.t.df[self.data_column].apply(lambda x: np.log(x))

        elif transform == 'modlog10':
            logmod = lambda x: np.sign(x) * (np.log10(np.abs(x) + 1))
            self.t.df[output_column] = self.t.df[self.data_column].apply(logmod)

        elif transform == 'modln':
            logmod = lambda x: np.sign(x) * (np.log(np.abs(x)) + 1)
            self.t.df[output_column] = self.t.df[self.data_column].apply(logmod)

        self.t.history_trace.add_operation(data_block_id='all', operation='log_transform', parameters=params)
        self.t.last_output = output_column

        return self.t


class Derivative(CtrlNode):
    """Return the Derivative of a curve."""
    nodeName = 'Derivative'
    uiTemplate = [('data_column', 'combo', {}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True})
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()
        if self.ctrls['Apply'].isChecked() is False:
            return

        self.t = transmission.copy()

        output_column = '_DERIVATIVE'

        self.t.df[output_column] = self.t.df[self.data_column].apply(np.gradient)
        self.t.last_output = output_column

        params = {'data_column': self.data_column,
                  'units': self.t.last_unit
                  }

        self.t.history_trace.add_operation(data_block_id='all', operation='derivative', parameters=params)

        return self.t


class TVDiff(CtrlNode):
    """Total Variation Regularized Numerical Differentiation, Chartrand 2011 method"""
    nodeName = 'TVDiff'
    uiTemplate = [('data_column', 'combo', {}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True}),
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()

        if self.ctrls['Apply'].isChecked() is False:
            return

        self.t = transmission.copy()

        output_column = '_TVDIFF'
        tqdm.pandas()
        self.t.df[output_column] = self.t.df[self.data_column].progress_apply(lambda x: self._func(x, 100, 1e-1, dx=0.05, ep=1e-2, scale='large', diagflag=0))
        self.t.last_output = output_column

        params = {'data_column': self.data_column,
                  'units': self.t.last_unit
                  }

        self.t.history_trace.add_operation(data_block_id='all', operation='tvdiff', parameters=params)

        return self.t

    def _func(self, *args, **kwargs):
        return tv_reg_diff(*args, **kwargs)


class Integrate(CtrlNode):
    pass


class ArrayStats(CtrlNode):
    """Perform various statistical functions"""
    nodeName = 'ArrayStats'
    uiTemplate = [('data_column', 'combo', {}),
                  ('function', 'combo', {'items': ['amin', 'amax', 'nanmin', 'nanmax', 'ptp', 'median', 'mean', 'std',
                                                   'var', 'nanmedian', 'nanmean', 'nanstd', 'nanvar']}),
                  ('group_by', 'combo', {}),
                  ('group_by_sec', 'combo', {}),
                  ('output_col', 'lineEdit', {}),
                  ('Apply', 'check', {'checked': False, 'applyBox': True})]

    def processData(self, transmission: Transmission):
        self.t = transmission
        dcols = organize_dataframe_columns(transmission.df.columns)[0]
        self.ctrls['data_column'].setItems(dcols)

        ccols = ['------'] + organize_dataframe_columns(self.t.df.columns)[1]
        self.ctrls['group_by'].setItems(ccols)
        self.ctrls['group_by_sec'].setItems(ccols)

        if not self.apply_checked():
            return

        self.t = transmission.copy()

        output_column = self.ctrls['output_col'].text()

        output_column = output_column.upper()
        if not output_column.startswith('_'):
            output_column = '_' + output_column

        function = self.ctrls['function'].currentText()

        if self.ctrls['group_by'].currentIndex() > 0:
            group_by = self.ctrls['group_by'].currentText()
        else:
            group_by = False

        if self.ctrls['group_by_sec'].currentIndex() > 0:
            group_by_sec = self.ctrls['group_by_sec'].currentText()
        else:
            group_by_sec = False

        params = {'data_column': self.data_column,
                  'output_column': output_column,
                  'function': function,
                  'group_by': group_by,
                  'group_by_sec': group_by_sec
                  }

        func = getattr(np, function)

        if group_by_sec:
            secondary_groups = self.t.df[group_by_sec].unique()
        else:
            secondary_groups = ['']

        if group_by:
            grouped_df = Transmission.empty_df(self.t, addCols=[f'{output_column}'])

            groups_primary = self.t.df[group_by].unique()

            for group in tqdm(groups_primary, total=groups_primary.size, desc='groups'):
                gdf = self.t.df[self.t.df[group_by] == group]

                for sgroup in secondary_groups:

                    if sgroup:
                        sgdf = gdf[gdf[group_by_sec] == sgroup]
                        s = sgdf.iloc[0].copy()

                    else:
                        sgdf = gdf
                        s = gdf.iloc[0].copy()

                    data = np.vstack(sgdf[self.data_column])
                    results = func(data, axis=0)

                    s[f'{output_column}'] = results

                    grouped_df = grouped_df.append(s, ignore_index=True)

            self.t.df = grouped_df
        else:
            self.t.df[output_column] = self.t.df[self.data_column].apply(lambda x: func(x))

        self.t.last_output = output_column

        self.t.history_trace.add_operation('all', 'array_stats', params)

        return self.t


class ArgGroupStat(CtrlNode):
    """Group by a certain column and return value of another column based on a data column statistic"""
    nodeName = 'ArgGroupStat'
    uiTemplate = [('data_column', 'combo', {}),
                  ('group_by', 'combo', {}),
                  ('return_col', 'combo', {}),
                  ('stat', 'combo', {'items': ['min', 'max']}),
                  ('Apply', 'check', {'applyBox': True, 'checked': False})
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()

        ccols = organize_dataframe_columns(self.t.df.columns)[1]
        self.ctrls['group_by'].setItems(ccols)

        self.ctrls['return_col'].setItems(self.t.df.columns.tolist())

        if not self.apply_checked():
            return

        self.t = transmission.copy()

        group_by = self.ctrls['group_by'].currentText()
        return_col = self.ctrls['return_col'].currentText()
        stat = self.ctrls['stat'].currentText()
        output_column = 'ARG_STAT'

        params = {'data_column': self.data_column,
                  'group_by': group_by,
                  'return_col': return_col,
                  'stat': stat,
                  'output_column': output_column
                  }

        out_df = Transmission.empty_df(self.t, addCols=['ARG_STAT'])

        for group in self.t.df[group_by].unique():
            gdf = self.t.df[self.t.df[group_by] == group]
            gdf.reset_index(drop=True, inplace=True)

            if stat == 'max':
                ix = gdf[self.data_column].idxmax()

            elif stat == 'min':
                ix = gdf[self.data_column].idxmin()

            s = gdf.iloc[ix].copy()
            s['ARG_STAT'] = s[return_col]

            out_df = out_df.append(s, ignore_index=True)

        self.t.df = out_df
        self.t.history_trace.add_operation('all', 'arg-group-stat', params)

        return self.t


class ZScore(CtrlNode):
    """
    Z-Score the input data. Uses scipy.stats.zscore.
    Computes over sub-DataFrames that are created according to the "group_by" column parameter
    """
    nodeName = 'ZScore'
    uiTemplate = [('data_column', 'combo', {}),
                  ('group_by', 'combo', {}),
                  ('Apply', 'check', {'applyBox': True, 'checked': False})
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()

        ccols = organize_dataframe_columns(self.t.df.columns)[1]
        self.ctrls['group_by'].setItems(ccols)

        if not self.apply_checked():
            return

        self.t = transmission.copy()

        group_by = self.ctrls['group_by'].currentText()
        output_column = '_ZSCORE'

        params = {'data_column': self.data_column,
                  'group_by': group_by,
                  'output_column': output_column
                  }

        out_dfs = []

        # Per group
        for group in self.t.df[group_by].unique():
            sub_df = self.t.df[self.t.df[group_by] == group].copy()

            data = np.vstack(sub_df[self.data_column].values)
            zdata = _zscore(data, axis=None)

            sub_df['_ZSCORE'] = zdata.tolist()

            out_dfs.append(sub_df)

        df = pd.concat(out_dfs).reset_index(drop=True)
        df['_ZSCORE'] = df._ZSCORE.apply(np.array)

        self.t.df = df

        self.t.history_trace.add_operation('all', 'zscore', params)
        self.t.last_output = '_ZSCORE'

        return self.t


class LinRegress(CtrlNode):
    """Linear Regression"""
    nodeName = 'LinRegress'
    uiTemplate = [('data_column', 'combo', {}),
                  ('Apply', 'check', {'applyBox': True, 'checked': False})
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()

        if not self.apply_checked():
            return

        self.t = transmission.copy()

        params = {'data_column': self.data_column}

        self.t.df[['_SLOPE', '_INTERCEPT', '_R-VALUE', '_P-VALUE', '_STDERR']] \
            = self.t.df[self.data_column].apply(lambda y: self._linreg(np.arange(y.size), y))

        self.t.history_trace.add_operation('all', 'linreg', params)
        self.t.last_output = None

        return self.t

    def _linreg(self, x, y):
        r = linregress(x=np.arange(y.size), y=y)

        return pd.Series({'_SLOPE': r[0],
                          '_INTERCEPT': r[1],
                          '_R-VALUE': r[2],
                          '_P-VALUE': r[3],
                          '_STDERR': r[4]})



from .common import *
from sklearn import cluster as skcluster
from ....common.configuration import HAS_TSLEARN
from warnings import warn
if HAS_TSLEARN:
    from ....plotting.widgets import KShapeWidget


class KShape(CtrlNode):
    """k-Shape clustering"""
    nodeName = "KShape"
    uiTemplate = [('ShowGUI', 'button', {'text': 'ShowGUI'})]

    def __init__(self, name):
        CtrlNode.__init__(self, name, terminals={'In': {'io': 'in', 'multi': True}, 'Out': {'io': 'out'}})
        self.output_transmission = False
        if HAS_TSLEARN:
            self.kshape_widget = KShapeWidget(parent=None)
            self.kshape_widget.sig_output_changed.connect(self._send_output)
            self.ctrls['ShowGUI'].clicked.connect(self.kshape_widget.show)
        else:
            warn("tslearn not installed, KShape is disabled.")

    def _send_output(self, t: Transmission):
        self.output_transmission = t
        self.changed()

    def process(self, output_transmission=False, **kwargs):
        if self.output_transmission:
            out = self.output_transmission
        else:
            out = self.processData(**kwargs)

        return {'Out': out}

    def processData(self, **kwargs):
        self.transmissions = kwargs['In']
        self.transmissions_list = merge_transmissions(self.transmissions)
        self.t = Transmission.merge(self.transmissions_list)
        self.kshape_widget.set_input(self.t)
        return None


class KMeans(CtrlNode):
    """KMeans clustering\nhttps://scikit-learn.org/stable/modules/generated/sklearn.cluster.KMeans.html\n
    Output column -> KMEANS_CLUSTER_<data_column>"""
    nodeName = "KMeans"
    uiTemplate = [('data_column', 'combo', {}),

                  ('n_clusters', 'intSpin',
                   {'max': 100, 'min': 2, 'value': 2, 'step': 1,
                    'toolTip': 'The number of clusters to form as well as the number of centroids to generate.'}),

                  ('n_init', 'intSpin',
                   {'max': 100, 'min': 1, 'value': 10, 'step': 10,
                    'toolTip': 'Number of time the k-means algorithm will be run with different centroid seeds.\n'
                               'The final results will be the best output of n_init consecutive runs in terms '
                               'of inertia.'}),

                  ('max_iter', 'intSpin',
                   {'max': 10000, 'min': 1, 'value': 300, 'step': 50,
                    'toolTip': 'Maximum number of iterations of the k-means algorithm for a single run.'}),

                  ('tol', 'doubleSpin',
                   {'max': 1.0, 'min': 0.0000001, 'step': 0.000001, 'value': 0.0001,
                    'toolTip': 'Relative tolerance with regards to inertia to declare convergence'}),

                  ('precompute_distances', 'combo',
                   {'items': ['auto', 'True', 'False']}),

                  ('Apply', 'check', {'checked': False, 'applyBox': True})
                  ]

    def processData(self, transmission: Transmission):
        self.t = transmission
        self.set_data_column_combo_box()

        if self.ctrls['Apply'].isChecked() is False:
            return

        self.t = transmission.copy()

        n_clusters = self.ctrls['n_clusters'].value()
        n_init = self.ctrls['n_init'].value()
        max_iter = self.ctrls['max_iter'].value()
        tol = self.ctrls['tol'].value()
        precompute_distances = self.ctrls['precompute_distances'].currentText()

        if precompute_distances == 'True':
            precompute_distances = True
        elif precompute_distances == 'False':
            precompute_distances = False

        self.data = np.vstack(self.t.df[self.data_column].values)

        output_column = 'KMEANS_CLUSTER_LABEL'

        self.kmeans = skcluster.KMeans(n_clusters=n_clusters, n_init=n_init, max_iter=max_iter, tol=tol,
                                       precompute_distances=precompute_distances)

        self.kmeans.fit(self.data)

        self.t.df[output_column] = self.kmeans.labels_

        params = {'data_column': self.data_column,
                  'n_init': n_init,
                  'max_iter': max_iter,
                  'tol': tol,
                  'precompute_distances': precompute_distances}
        self.t.history_trace.add_operation(data_block_id='all', operation='kmeans_clustering', parameters=params)
        self.t.last_output = output_column

        return self.t


# class LDA(CtrlNode):
#     """LDA"""
#     nodeName = 'LDA'
#     uiTemplate = [('Apply', 'check', {'checked': False, 'applyBox': True}),
#                   ('ShowGUI', 'button', {'text': 'OpenGUI'})]
#
#     def __init__(self, name):
#         CtrlNode.__init__(self, name, terminals={'In': {'io': 'in', 'multi': True}})
#         self.plot_widget = None
#         self.ctrls['ShowGUI'].clicked.connect(self._open_plot_gui)
#
#     def process(self, **kwargs):
#         if (self.ctrls['Apply'].isChecked() is False) or self.plot_widget is None:
#             return
#
#         transmissions = kwargs['In']
#
#         transmissions_list = merge_transmissions(transmissions)
#
#         self.plot_widget.update_input_transmissions(transmissions_list)
#
#     def _open_plot_gui(self):
#         if self.plot_widget is None:
#             self.plot_widget = LDAPlot()
#         self.plot_widget.show()





# @author: kushal

# Chatzigeorgiou Group
# Sars International Centre for Marine Molecular Biology

# GNU GENERAL PUBLIC LICENSE Version 3, 29 June 2007

import os
from webbrowser import open_new_tab as open_new_web_browser_tab
import configparser
from datetime import datetime
from time import time
from .configuration import get_sys_config, console_history_path
from functools import partial
from PyQt5.QtWidgets import QApplication
from abc import ABCMeta
from pathlib import Path


with open(Path(__file__).parent.parent.joinpath('VERSION'), 'r') as vf:
    __version__ = vf.read().split('\n')[0]


def get_proj_config(proj_path: str = None) -> configparser.RawConfigParser:
    """
    :param proj_path: Full project path
    """

    if proj_path is None:
        proj_path = get_project_manager().root_dir
        if proj_path is None:
            raise NoProjectOpen

    proj_cfg = configparser.RawConfigParser(allow_no_value=True)
    proj_cfg.optionxform = str
    proj_cfg.read(proj_path + '/config.cfg')
    return proj_cfg


docs_dir = f'https://docs.mesmerizelab.org/en/v{__version__}/'

doc_pages = \
    {
        'issue-tracker':    'https://github.com/kushalkolar/MESmerize/issues',
        'gitter':           'https://gitter.im/mesmerize_discussion/community'
    }

mesmerize_doc_pages = \
    {
        'home':             '',
        'new_project':      'user_guides/project_organization/new_project/new_project.html',
        'viewer':           'user_guides/viewer/overview.html',
        'faq':              'user_guides/faq.html',
        'sys_config':       'user_guides/general/misc.html#system-configuration'
    }

doc_pages.update(
    {k: docs_dir + v for k, v in mesmerize_doc_pages.items()}
)


for k in doc_pages.keys():
    doc_pages[k] = partial(open_new_web_browser_tab, doc_pages[k])


class InheritDocs(ABCMeta):
    """Inherit doc string from superclass if not present in subclass"""

    def __new__(mcls, classname, bases, cls_dict):
        cls = super().__new__(mcls, classname, bases, cls_dict)
        for name, member in cls_dict.items():
            if not getattr(member, '__doc__'):
                if hasattr(bases[-1], name):
                    member.__doc__ = getattr(bases[-1], name).__doc__
        return cls


def get_timestamp_str() -> str:
    date = datetime.fromtimestamp(time())
    time_str = date.strftime('%Y%m%d') + '_' + date.strftime('%H%M%S')
    return time_str


def is_app() -> bool:
    if QApplication.instance() is None:
        return False

    if hasattr(QApplication.instance(), 'window_manager') and hasattr(QApplication.instance(), 'project_manager'):
        return True

    return False


def get_project_manager():
    """Get the project manager for this Mesmerize instance"""
    if not is_app():
        raise NotInApplicationError

    pm = getattr(QApplication.instance(), 'project_manager')
    return pm


def set_project_manager(project_manager):
    if not is_app():
        raise NotInApplicationError

    setattr(QApplication.instance(), 'project_manager', project_manager)


def get_window_manager():
    """Get the Window Manager for this Mesmerize instance"""

    if not is_app():
        raise NotInApplicationError
    return getattr(QApplication.instance(), 'window_manager')
    # try:
    #     wm = getattr(QApplication.instance(), 'window_manager')
    # except AttributeError:
    #     raise AttributeError("This can only be used in a full Mesmerize Application")
    # return wm


def get_session_id():
    if not is_app():
        raise NotInApplicationError
    return getattr(QApplication.instance(), 'session_id')


def is_mesmerize_project(proj_dir: str) -> bool:
    if not os.path.isdir(proj_dir + '/dataframes'):
        raise NotAMesmerizeProject('dataframes directory not found')

    if not os.path.isdir(proj_dir + '/images'):
        raise NotAMesmerizeProject('images directory not found')

    return True


class NoProjectOpen(Exception):
    """No Mesmerize project is open."""


class NotInApplicationError(Exception):
    """This can only be used in a full Mesmerize Application"""


class NotAMesmerizeProject(Exception):
    """Not a valid Mesmerize Project"""

    def __init__(self, msg):
        assert isinstance(msg, str)
        self.msg = msg

    def __str__(self):
        return str(self.__doc__) + '\n' + self.msg



from PyQt5 import QtWidgets

# You must define module_name.
# This is the name that will be displayed in the Custom Modules menu of the Viewer Window.
# You can also use this to reference ModuleGUI instance through the Viewer Console via ``get_module(<module_name>)``

module_name = 'Example Module'


# The main GUI class MUST be named ModuleGUI.
# You can have other classes and GUIs but this is the one that the viewer directly calls.

class ModuleGUI(QtWidgets.QDockWidget):
# The viewer MainWindow instance will pass a viewer instance
# that can be used to interact with the viewer and work environment.
    def __init__(self, parent, viewer_instance):
        QtWidgets.QDockWidget.__init__(self, parent)
        self.setFloating(True) # Must be floating



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'stats_peak_plots_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_stats_peak_plots_template(object):
    def setupUi(self, stats_peak_plots_template):
        stats_peak_plots_template.setObjectName("stats_peak_plots_template")
        stats_peak_plots_template.resize(709, 402)
        self.gridLayout = QtWidgets.QGridLayout(stats_peak_plots_template)
        self.gridLayout.setObjectName("gridLayout")
        self.label = QtWidgets.QLabel(stats_peak_plots_template)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(stats_peak_plots_template)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 0, 1, 1, 1)
        self.curve_plot_all_group_peaks = PlotWidget(stats_peak_plots_template)
        self.curve_plot_all_group_peaks.setObjectName("curve_plot_all_group_peaks")
        self.gridLayout.addWidget(self.curve_plot_all_group_peaks, 1, 0, 1, 1)
        self.curve_plot_group_peaks = GraphicsLayoutWidget(stats_peak_plots_template)
        self.curve_plot_group_peaks.setObjectName("curve_plot_group_peaks")
        self.gridLayout.addWidget(self.curve_plot_group_peaks, 1, 1, 1, 1)
        self.label_3 = QtWidgets.QLabel(stats_peak_plots_template)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 2, 0, 1, 1)
        self.headmap_all_group_peaks = QtWidgets.QWidget(stats_peak_plots_template)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headmap_all_group_peaks.sizePolicy().hasHeightForWidth())
        self.headmap_all_group_peaks.setSizePolicy(sizePolicy)
        self.headmap_all_group_peaks.setMinimumSize(QtCore.QSize(250, 190))
        self.headmap_all_group_peaks.setObjectName("headmap_all_group_peaks")
        self.gridLayout.addWidget(self.headmap_all_group_peaks, 3, 0, 1, 1)

        self.retranslateUi(stats_peak_plots_template)
        QtCore.QMetaObject.connectSlotsByName(stats_peak_plots_template)

    def retranslateUi(self, stats_peak_plots_template):
        _translate = QtCore.QCoreApplication.translate
        stats_peak_plots_template.setWindowTitle(_translate("stats_peak_plots_template", "Form"))
        self.label.setText(_translate("stats_peak_plots_template", "Peak traces - all groups. x0 = peak maxima"))
        self.label_2.setText(_translate("stats_peak_plots_template", "Peak traces - one subplot per group"))
        self.label_3.setText(_translate("stats_peak_plots_template", "Heatmaps of peaks - all groups, center = peak maxima"))

from pyqtgraphCore import GraphicsLayoutWidget, PlotWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './ui_files/suite2p_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockWidgetSuite2p(object):
    def setupUi(self, DockWidgetSuite2p):
        DockWidgetSuite2p.setObjectName("DockWidgetSuite2p")
        DockWidgetSuite2p.resize(735, 386)
        DockWidgetSuite2p.setFloating(True)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label_2 = QtWidgets.QLabel(self.dockWidgetContents)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.label_2.setFont(font)
        self.label_2.setWordWrap(True)
        self.label_2.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.label_2.setObjectName("label_2")
        self.verticalLayout.addWidget(self.label_2)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_dir = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton_dir.setObjectName("pushButton_dir")
        self.horizontalLayout_2.addWidget(self.pushButton_dir)
        self.label_dir = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_dir.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.label_dir.setObjectName("label_dir")
        self.horizontalLayout_2.addWidget(self.label_dir)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.spinBox_Fneu_sub = QtWidgets.QSpinBox(self.dockWidgetContents)
        self.spinBox_Fneu_sub.setMaximum(100)
        self.spinBox_Fneu_sub.setSingleStep(10)
        self.spinBox_Fneu_sub.setProperty("value", 70)
        self.spinBox_Fneu_sub.setObjectName("spinBox_Fneu_sub")
        self.horizontalLayout_10.addWidget(self.spinBox_Fneu_sub)
        self.label = QtWidgets.QLabel(self.dockWidgetContents)
        self.label.setObjectName("label")
        self.horizontalLayout_10.addWidget(self.label)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_10)
        self.checkBox_use_iscell = QtWidgets.QCheckBox(self.dockWidgetContents)
        self.checkBox_use_iscell.setObjectName("checkBox_use_iscell")
        self.verticalLayout.addWidget(self.checkBox_use_iscell)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.pushButton_import = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton_import.setObjectName("pushButton_import")
        self.horizontalLayout_3.addWidget(self.pushButton_import)
        spacerItem2 = QtWidgets.QSpacerItem(37, 17, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem2)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        DockWidgetSuite2p.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidgetSuite2p)
        QtCore.QMetaObject.connectSlotsByName(DockWidgetSuite2p)
        DockWidgetSuite2p.setTabOrder(self.pushButton_dir, self.spinBox_Fneu_sub)
        DockWidgetSuite2p.setTabOrder(self.spinBox_Fneu_sub, self.checkBox_use_iscell)
        DockWidgetSuite2p.setTabOrder(self.checkBox_use_iscell, self.pushButton_import)

    def retranslateUi(self, DockWidgetSuite2p):
        _translate = QtCore.QCoreApplication.translate
        DockWidgetSuite2p.setWindowTitle(_translate("DockWidgetSuite2p", "S&uite2p importer"))
        self.label_2.setText(_translate("DockWidgetSuite2p", "Select the directory which contains the Suite2p output data that corresponds to the current image sequence.\n"
"\n"
"The dir must contain the following files:\n"
"  F.npy\n"
"  Fneu.npy\n"
"  stat.npy\n"
"  ops.npy\n"
"  iscell.npy"))
        self.pushButton_dir.setToolTip(_translate("DockWidgetSuite2p", "Choose a dir containing suite2p output data"))
        self.pushButton_dir.setText(_translate("DockWidgetSuite2p", "select dir"))
        self.label_dir.setText(_translate("DockWidgetSuite2p", "<not selected>"))
        self.spinBox_Fneu_sub.setToolTip(_translate("DockWidgetSuite2p", "substracts this much of Fneu from F to get the final trace"))
        self.label.setText(_translate("DockWidgetSuite2p", "Fneu substraction (%)"))
        self.checkBox_use_iscell.setText(_translate("DockWidgetSuite2p", "only import ROIs that were classified as cells by suite2p (uses iscell.npy)"))
        self.pushButton_import.setText(_translate("DockWidgetSuite2p", "Import"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'stim_plots_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_stim_plots_template(object):
    def setupUi(self, stim_plots_template):
        stim_plots_template.setObjectName("stim_plots_template")
        stim_plots_template.resize(767, 411)
        self.gridLayout = QtWidgets.QGridLayout(stim_plots_template)
        self.gridLayout.setObjectName("gridLayout")
        self.label_4 = QtWidgets.QLabel(stim_plots_template)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 0, 0, 1, 1)
        self.label_5 = QtWidgets.QLabel(stim_plots_template)
        self.label_5.setObjectName("label_5")
        self.gridLayout.addWidget(self.label_5, 0, 1, 1, 1)
        self.stim_plots_overlays = PlotWidget(stim_plots_template)
        self.stim_plots_overlays.setObjectName("stim_plots_overlays")
        self.gridLayout.addWidget(self.stim_plots_overlays, 1, 0, 1, 1)
        self.stim_plots_groups = GraphicsLayoutWidget(stim_plots_template)
        self.stim_plots_groups.setObjectName("stim_plots_groups")
        self.gridLayout.addWidget(self.stim_plots_groups, 1, 1, 1, 1)
        self.label_6 = QtWidgets.QLabel(stim_plots_template)
        self.label_6.setObjectName("label_6")
        self.gridLayout.addWidget(self.label_6, 2, 0, 1, 1)
        self.headmaps_widget = QtWidgets.QWidget(stim_plots_template)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.headmaps_widget.sizePolicy().hasHeightForWidth())
        self.headmaps_widget.setSizePolicy(sizePolicy)
        self.headmaps_widget.setMinimumSize(QtCore.QSize(250, 190))
        self.headmaps_widget.setObjectName("headmaps_widget")
        self.gridLayout.addWidget(self.headmaps_widget, 3, 0, 1, 1)

        self.retranslateUi(stim_plots_template)
        QtCore.QMetaObject.connectSlotsByName(stim_plots_template)

    def retranslateUi(self, stim_plots_template):
        _translate = QtCore.QCoreApplication.translate
        stim_plots_template.setWindowTitle(_translate("stim_plots_template", "Form"))
        self.label_4.setText(_translate("stim_plots_template", "All groups"))
        self.label_5.setText(_translate("stim_plots_template", "Group subplots"))
        self.label_6.setText(_translate("stim_plots_template", "Heatmaps all groups"))

from pyqtgraphCore import GraphicsLayoutWidget, PlotWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './window_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1231, 701)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.splitter_2 = QtWidgets.QSplitter(self.centralwidget)
        self.splitter_2.setOrientation(QtCore.Qt.Horizontal)
        self.splitter_2.setObjectName("splitter_2")
        self.layoutWidget = QtWidgets.QWidget(self.splitter_2)
        self.layoutWidget.setObjectName("layoutWidget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.layoutWidget)
        self.verticalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(2)
        sizePolicy.setHeightForWidth(self.groupBox.sizePolicy().hasHeightForWidth())
        self.groupBox.setSizePolicy(sizePolicy)
        self.groupBox.setObjectName("groupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label = QtWidgets.QLabel(self.groupBox)
        self.label.setObjectName("label")
        self.verticalLayout_2.addWidget(self.label)
        self.listWidgetDataColumns = QtWidgets.QListWidget(self.groupBox)
        self.listWidgetDataColumns.setAlternatingRowColors(True)
        self.listWidgetDataColumns.setSelectionMode(QtWidgets.QAbstractItemView.ExtendedSelection)
        self.listWidgetDataColumns.setObjectName("listWidgetDataColumns")
        self.verticalLayout_2.addWidget(self.listWidgetDataColumns)
        self.label_group = QtWidgets.QLabel(self.groupBox)
        self.label_group.setObjectName("label_group")
        self.verticalLayout_2.addWidget(self.label_group)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.radioButtonGroupBySingleColumn = QtWidgets.QRadioButton(self.groupBox)
        self.radioButtonGroupBySingleColumn.setMaximumSize(QtCore.QSize(16, 16777215))
        self.radioButtonGroupBySingleColumn.setText("")
        self.radioButtonGroupBySingleColumn.setChecked(True)
        self.radioButtonGroupBySingleColumn.setObjectName("radioButtonGroupBySingleColumn")
        self.horizontalLayout_3.addWidget(self.radioButtonGroupBySingleColumn)
        self.comboBoxGrouping = QtWidgets.QComboBox(self.groupBox)
        self.comboBoxGrouping.setObjectName("comboBoxGrouping")
        self.horizontalLayout_3.addWidget(self.comboBoxGrouping)
        self.verticalLayout_2.addLayout(self.horizontalLayout_3)
        self.checkBoxUseDifferentShapes = QtWidgets.QCheckBox(self.groupBox)
        self.checkBoxUseDifferentShapes.setObjectName("checkBoxUseDifferentShapes")
        self.verticalLayout_2.addWidget(self.checkBoxUseDifferentShapes)
        self.comboBoxShape = QtWidgets.QComboBox(self.groupBox)
        self.comboBoxShape.setObjectName("comboBoxShape")
        self.verticalLayout_2.addWidget(self.comboBoxShape)
        self.labelDatapointTracerCurve = QtWidgets.QLabel(self.groupBox)
        self.labelDatapointTracerCurve.setObjectName("labelDatapointTracerCurve")
        self.verticalLayout_2.addWidget(self.labelDatapointTracerCurve)
        self.comboBoxDataPointTracerCurveColumn = QtWidgets.QComboBox(self.groupBox)
        self.comboBoxDataPointTracerCurveColumn.setObjectName("comboBoxDataPointTracerCurveColumn")
        self.verticalLayout_2.addWidget(self.comboBoxDataPointTracerCurveColumn)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.radioButtonGroupByTransmissions = QtWidgets.QRadioButton(self.groupBox)
        self.radioButtonGroupByTransmissions.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.radioButtonGroupByTransmissions.setObjectName("radioButtonGroupByTransmissions")
        self.horizontalLayout_4.addWidget(self.radioButtonGroupByTransmissions)
        self.btnSetIncomingTransmissionsNames = QtWidgets.QPushButton(self.groupBox)
        self.btnSetIncomingTransmissionsNames.setObjectName("btnSetIncomingTransmissionsNames")
        self.horizontalLayout_4.addWidget(self.btnSetIncomingTransmissionsNames)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.btnEditColor = QtWidgets.QPushButton(self.groupBox)
        self.btnEditColor.setObjectName("btnEditColor")
        self.verticalLayout_2.addWidget(self.btnEditColor)
        self.label_3 = QtWidgets.QLabel(self.groupBox)
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.comboBoxUUIDColumn = QtWidgets.QComboBox(self.groupBox)
        self.comboBoxUUIDColumn.setObjectName("comboBoxUUIDColumn")
        self.verticalLayout_2.addWidget(self.comboBoxUUIDColumn)
        self.verticalLayout_3.addWidget(self.groupBox)
        self.groupBoxSpecific = QtWidgets.QGroupBox(self.layoutWidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(1)
        sizePolicy.setHeightForWidth(self.groupBoxSpecific.sizePolicy().hasHeightForWidth())
        self.groupBoxSpecific.setSizePolicy(sizePolicy)
        self.groupBoxSpecific.setObjectName("groupBoxSpecific")
        self.verticalLayout_3.addWidget(self.groupBoxSpecific)
        self.btnApplyAll = QtWidgets.QPushButton(self.layoutWidget)
        self.btnApplyAll.setObjectName("btnApplyAll")
        self.verticalLayout_3.addWidget(self.btnApplyAll)
        self.tabWidget = QtWidgets.QTabWidget(self.splitter_2)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(1)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.tabWidget.sizePolicy().hasHeightForWidth())
        self.tabWidget.setSizePolicy(sizePolicy)
        self.tabWidget.setObjectName("tabWidget")
        self.verticalLayout_4.addWidget(self.splitter_2)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1231, 30))
        self.menubar.setObjectName("menubar")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.dockConsole = QtWidgets.QDockWidget(MainWindow)
        self.dockConsole.setObjectName("dockConsole")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.dockConsole.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(8), self.dockConsole)
        self.actionConsole = QtWidgets.QAction(MainWindow)
        self.actionConsole.setCheckable(True)
        self.actionConsole.setObjectName("actionConsole")
        self.actionLive_datapoint_tracer = QtWidgets.QAction(MainWindow)
        self.actionLive_datapoint_tracer.setCheckable(False)
        self.actionLive_datapoint_tracer.setObjectName("actionLive_datapoint_tracer")
        self.menuView.addAction(self.actionConsole)
        self.menuView.addAction(self.actionLive_datapoint_tracer)
        self.menubar.addAction(self.menuView.menuAction())

        self.retranslateUi(MainWindow)
        self.tabWidget.setCurrentIndex(-1)
        self.actionConsole.toggled['bool'].connect(self.dockConsole.setVisible)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.groupBox.setTitle(_translate("MainWindow", "Plot controls"))
        self.label.setText(_translate("MainWindow", "Data columns"))
        self.label_group.setText(_translate("MainWindow", "Group based on:"))
        self.checkBoxUseDifferentShapes.setText(_translate("MainWindow", "Use different shapes based on:"))
        self.labelDatapointTracerCurve.setText(_translate("MainWindow", "Datapoint tracer curve:"))
        self.radioButtonGroupByTransmissions.setText(_translate("MainWindow", "Inco&ming transmissions"))
        self.btnSetIncomingTransmissionsNames.setText(_translate("MainWindow", "Set Names"))
        self.btnEditColor.setText(_translate("MainWindow", "Edit colors"))
        self.label_3.setText(_translate("MainWindow", "UUID column:"))
        self.groupBoxSpecific.setTitle(_translate("MainWindow", "More controls"))
        self.btnApplyAll.setText(_translate("MainWindow", "Apply All"))
        self.menuView.setTitle(_translate("MainWindow", "&View"))
        self.dockConsole.setWindowTitle(_translate("MainWindow", "&Console: Plot Window"))
        self.actionConsole.setText(_translate("MainWindow", "&Console"))
        self.actionLive_datapoint_tracer.setText(_translate("MainWindow", "&Live datapoint tracer"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'datapoint_tracer.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DatapointTracer(object):
    def setupUi(self, DatapointTracer):
        DatapointTracer.setObjectName("DatapointTracer")
        DatapointTracer.resize(1043, 697)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(DatapointTracer)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label = QtWidgets.QLabel(DatapointTracer)
        self.label.setMinimumSize(QtCore.QSize(50, 0))
        self.label.setMaximumSize(QtCore.QSize(60, 16777215))
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout_3.addWidget(self.label)
        self.lineEditUUID = QtWidgets.QLineEdit(DatapointTracer)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.lineEditUUID.setFont(font)
        self.lineEditUUID.setReadOnly(True)
        self.lineEditUUID.setObjectName("lineEditUUID")
        self.horizontalLayout_3.addWidget(self.lineEditUUID)
        self.verticalLayout_3.addLayout(self.horizontalLayout_3)
        self.splitterMain = QtWidgets.QSplitter(DatapointTracer)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitterMain.sizePolicy().hasHeightForWidth())
        self.splitterMain.setSizePolicy(sizePolicy)
        self.splitterMain.setOrientation(QtCore.Qt.Horizontal)
        self.splitterMain.setObjectName("splitterMain")
        self.groupBoxInfo = QtWidgets.QGroupBox(self.splitterMain)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(3)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxInfo.sizePolicy().hasHeightForWidth())
        self.groupBoxInfo.setSizePolicy(sizePolicy)
        self.groupBoxInfo.setObjectName("groupBoxInfo")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.groupBoxInfo)
        self.verticalLayout.setObjectName("verticalLayout")
        self.pushButtonOpenInViewer = QtWidgets.QPushButton(self.groupBoxInfo)
        self.pushButtonOpenInViewer.setObjectName("pushButtonOpenInViewer")
        self.verticalLayout.addWidget(self.pushButtonOpenInViewer)
        self.pushButtonOpenAnalysisGraph = QtWidgets.QPushButton(self.groupBoxInfo)
        self.pushButtonOpenAnalysisGraph.setObjectName("pushButtonOpenAnalysisGraph")
        self.verticalLayout.addWidget(self.pushButtonOpenAnalysisGraph)
        self.groupBoxImageViewAndCurve = QtWidgets.QGroupBox(self.splitterMain)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBoxImageViewAndCurve.sizePolicy().hasHeightForWidth())
        self.groupBoxImageViewAndCurve.setSizePolicy(sizePolicy)
        self.groupBoxImageViewAndCurve.setObjectName("groupBoxImageViewAndCurve")
        self.verticalLayout_groupBoxImageViewAndCurve = QtWidgets.QVBoxLayout(self.groupBoxImageViewAndCurve)
        self.verticalLayout_groupBoxImageViewAndCurve.setObjectName("verticalLayout_groupBoxImageViewAndCurve")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_zlevel = QtWidgets.QLabel(self.groupBoxImageViewAndCurve)
        self.label_zlevel.setText("")
        self.label_zlevel.setObjectName("label_zlevel")
        self.horizontalLayout_2.addWidget(self.label_zlevel)
        self.radioButtonMaxProjection = QtWidgets.QRadioButton(self.groupBoxImageViewAndCurve)
        self.radioButtonMaxProjection.setChecked(True)
        self.radioButtonMaxProjection.setObjectName("radioButtonMaxProjection")
        self.horizontalLayout_2.addWidget(self.radioButtonMaxProjection)
        self.radioButtonSTDProjection = QtWidgets.QRadioButton(self.groupBoxImageViewAndCurve)
        self.radioButtonSTDProjection.setObjectName("radioButtonSTDProjection")
        self.horizontalLayout_2.addWidget(self.radioButtonSTDProjection)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout_groupBoxImageViewAndCurve.addLayout(self.horizontalLayout_2)
        self.splitterImageViewAndCurve = QtWidgets.QSplitter(self.groupBoxImageViewAndCurve)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(10)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.splitterImageViewAndCurve.sizePolicy().hasHeightForWidth())
        self.splitterImageViewAndCurve.setSizePolicy(sizePolicy)
        self.splitterImageViewAndCurve.setOrientation(QtCore.Qt.Vertical)
        self.splitterImageViewAndCurve.setObjectName("splitterImageViewAndCurve")
        self.graphicsViewImage = GraphicsLayoutWidget(self.splitterImageViewAndCurve)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(10)
        sizePolicy.setHeightForWidth(self.graphicsViewImage.sizePolicy().hasHeightForWidth())
        self.graphicsViewImage.setSizePolicy(sizePolicy)
        self.graphicsViewImage.setObjectName("graphicsViewImage")
        self.graphicsViewPlot = PlotWidget(self.splitterImageViewAndCurve)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(3)
        sizePolicy.setHeightForWidth(self.graphicsViewPlot.sizePolicy().hasHeightForWidth())
        self.graphicsViewPlot.setSizePolicy(sizePolicy)
        self.graphicsViewPlot.setObjectName("graphicsViewPlot")
        self.verticalLayout_groupBoxImageViewAndCurve.addWidget(self.splitterImageViewAndCurve)
        self.verticalLayout_3.addWidget(self.splitterMain)

        self.retranslateUi(DatapointTracer)
        QtCore.QMetaObject.connectSlotsByName(DatapointTracer)

    def retranslateUi(self, DatapointTracer):
        _translate = QtCore.QCoreApplication.translate
        DatapointTracer.setWindowTitle(_translate("DatapointTracer", "Form"))
        self.label.setText(_translate("DatapointTracer", "UUID:"))
        self.groupBoxInfo.setTitle(_translate("DatapointTracer", "Info"))
        self.pushButtonOpenInViewer.setText(_translate("DatapointTracer", "Open in viewer"))
        self.pushButtonOpenAnalysisGraph.setText(_translate("DatapointTracer", "Open Analysis Graph"))
        self.groupBoxImageViewAndCurve.setTitle(_translate("DatapointTracer", "Image"))
        self.radioButtonMaxProjection.setText(_translate("DatapointTracer", "&Max Projection"))
        self.radioButtonSTDProjection.setText(_translate("DatapointTracer", "Standard De&viation Projection"))

from ...pyqtgraphCore import GraphicsLayoutWidget, PlotWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './template.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1146, 661)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setPointSize(16)
        font.setBold(True)
        font.setWeight(75)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.horizontalLayout_3.addWidget(self.label)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.btnModeView = QtWidgets.QPushButton(self.centralwidget)
        self.btnModeView.setMinimumSize(QtCore.QSize(0, 36))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnModeView.setFont(font)
        self.btnModeView.setCheckable(True)
        self.btnModeView.setObjectName("btnModeView")
        self.horizontalLayout.addWidget(self.btnModeView)
        self.btnModeDrag = QtWidgets.QPushButton(self.centralwidget)
        self.btnModeDrag.setMinimumSize(QtCore.QSize(0, 36))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnModeDrag.setFont(font)
        self.btnModeDrag.setCheckable(True)
        self.btnModeDrag.setObjectName("btnModeDrag")
        self.horizontalLayout.addWidget(self.btnModeDrag)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.btnModeAddPeaks = QtWidgets.QPushButton(self.centralwidget)
        self.btnModeAddPeaks.setMinimumSize(QtCore.QSize(0, 36))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnModeAddPeaks.setFont(font)
        self.btnModeAddPeaks.setCheckable(True)
        self.btnModeAddPeaks.setObjectName("btnModeAddPeaks")
        self.horizontalLayout_2.addWidget(self.btnModeAddPeaks)
        self.btnModeAddBases = QtWidgets.QPushButton(self.centralwidget)
        self.btnModeAddBases.setMinimumSize(QtCore.QSize(0, 36))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnModeAddBases.setFont(font)
        self.btnModeAddBases.setCheckable(True)
        self.btnModeAddBases.setObjectName("btnModeAddBases")
        self.horizontalLayout_2.addWidget(self.btnModeAddBases)
        self.btnModeDelete = QtWidgets.QPushButton(self.centralwidget)
        self.btnModeDelete.setMinimumSize(QtCore.QSize(0, 36))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnModeDelete.setFont(font)
        self.btnModeDelete.setCheckable(True)
        self.btnModeDelete.setObjectName("btnModeDelete")
        self.horizontalLayout_2.addWidget(self.btnModeDelete)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_4.addLayout(self.verticalLayout)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setObjectName("label_3")
        self.gridLayout.addWidget(self.label_3, 0, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.centralwidget)
        self.label_4.setObjectName("label_4")
        self.gridLayout.addWidget(self.label_4, 0, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 0, 2, 1, 1)
        self.sliderDotSize = QtWidgets.QSlider(self.centralwidget)
        self.sliderDotSize.setMinimum(5)
        self.sliderDotSize.setMaximum(50)
        self.sliderDotSize.setSingleStep(5)
        self.sliderDotSize.setPageStep(5)
        self.sliderDotSize.setProperty("value", 15)
        self.sliderDotSize.setOrientation(QtCore.Qt.Horizontal)
        self.sliderDotSize.setObjectName("sliderDotSize")
        self.gridLayout.addWidget(self.sliderDotSize, 1, 0, 1, 3)
        self.verticalLayout_2.addLayout(self.gridLayout)
        self.btnSetPeaksAtRelativeMaxima = QtWidgets.QPushButton(self.centralwidget)
        self.btnSetPeaksAtRelativeMaxima.setMinimumSize(QtCore.QSize(125, 55))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnSetPeaksAtRelativeMaxima.setFont(font)
        self.btnSetPeaksAtRelativeMaxima.setObjectName("btnSetPeaksAtRelativeMaxima")
        self.verticalLayout_2.addWidget(self.btnSetPeaksAtRelativeMaxima)
        self.horizontalLayout_4.addLayout(self.verticalLayout_2)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.btnSaveCurve = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSaveCurve.sizePolicy().hasHeightForWidth())
        self.btnSaveCurve.setSizePolicy(sizePolicy)
        self.btnSaveCurve.setMinimumSize(QtCore.QSize(96, 72))
        self.btnSaveCurve.setMaximumSize(QtCore.QSize(360, 73))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnSaveCurve.setFont(font)
        self.btnSaveCurve.setObjectName("btnSaveCurve")
        self.verticalLayout_4.addWidget(self.btnSaveCurve)
        self.btnClearCurve = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnClearCurve.sizePolicy().hasHeightForWidth())
        self.btnClearCurve.setSizePolicy(sizePolicy)
        self.btnClearCurve.setMinimumSize(QtCore.QSize(96, 72))
        self.btnClearCurve.setMaximumSize(QtCore.QSize(360, 73))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnClearCurve.setFont(font)
        self.btnClearCurve.setObjectName("btnClearCurve")
        self.verticalLayout_4.addWidget(self.btnClearCurve)
        self.horizontalLayout_4.addLayout(self.verticalLayout_4)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.btnDisconnectFromFlowchart = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnDisconnectFromFlowchart.sizePolicy().hasHeightForWidth())
        self.btnDisconnectFromFlowchart.setSizePolicy(sizePolicy)
        self.btnDisconnectFromFlowchart.setMinimumSize(QtCore.QSize(220, 30))
        self.btnDisconnectFromFlowchart.setMaximumSize(QtCore.QSize(340, 80))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnDisconnectFromFlowchart.setFont(font)
        self.btnDisconnectFromFlowchart.setCheckable(True)
        self.btnDisconnectFromFlowchart.setObjectName("btnDisconnectFromFlowchart")
        self.horizontalLayout_6.addWidget(self.btnDisconnectFromFlowchart)
        self.btnSendToFlowchart = QtWidgets.QPushButton(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.btnSendToFlowchart.sizePolicy().hasHeightForWidth())
        self.btnSendToFlowchart.setSizePolicy(sizePolicy)
        self.btnSendToFlowchart.setMinimumSize(QtCore.QSize(220, 30))
        self.btnSendToFlowchart.setMaximumSize(QtCore.QSize(340, 80))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.btnSendToFlowchart.setFont(font)
        self.btnSendToFlowchart.setObjectName("btnSendToFlowchart")
        self.horizontalLayout_6.addWidget(self.btnSendToFlowchart)
        self.verticalLayout_3.addLayout(self.horizontalLayout_6)
        self.pushButtonOpenInViewer = QtWidgets.QPushButton(self.centralwidget)
        self.pushButtonOpenInViewer.setObjectName("pushButtonOpenInViewer")
        self.verticalLayout_3.addWidget(self.pushButtonOpenInViewer)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_5.addWidget(self.label_2)
        self.lineEditSampleID = QtWidgets.QLineEdit(self.centralwidget)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.lineEditSampleID.setFont(font)
        self.lineEditSampleID.setReadOnly(True)
        self.lineEditSampleID.setObjectName("lineEditSampleID")
        self.horizontalLayout_5.addWidget(self.lineEditSampleID)
        self.verticalLayout_3.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_4.addLayout(self.verticalLayout_3)
        self.verticalLayout_5.addLayout(self.horizontalLayout_4)
        self.graphicsView = PlotWidget(self.centralwidget)
        self.graphicsView.setObjectName("graphicsView")
        self.verticalLayout_5.addWidget(self.graphicsView)
        self.listwIndices = QtWidgets.QListWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.listwIndices.sizePolicy().hasHeightForWidth())
        self.listwIndices.setSizePolicy(sizePolicy)
        self.listwIndices.setMinimumSize(QtCore.QSize(0, 33))
        self.listwIndices.setMaximumSize(QtCore.QSize(16777215, 33))
        self.listwIndices.setProperty("showDropIndicator", False)
        self.listwIndices.setDefaultDropAction(QtCore.Qt.IgnoreAction)
        self.listwIndices.setSelectionMode(QtWidgets.QAbstractItemView.SingleSelection)
        self.listwIndices.setFlow(QtWidgets.QListView.LeftToRight)
        self.listwIndices.setObjectName("listwIndices")
        self.verticalLayout_5.addWidget(self.listwIndices)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1146, 22))
        self.menubar.setObjectName("menubar")
        self.menuView = QtWidgets.QMenu(self.menubar)
        self.menuView.setObjectName("menuView")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.dockWidget = QtWidgets.QDockWidget(MainWindow)
        self.dockWidget.setMinimumSize(QtCore.QSize(200, 50))
        self.dockWidget.setObjectName("dockWidget")
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.dockWidget.setWidget(self.dockWidgetContents)
        MainWindow.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget)
        self.actionUndo = QtWidgets.QAction(MainWindow)
        self.actionUndo.setObjectName("actionUndo")
        self.actionRedo = QtWidgets.QAction(MainWindow)
        self.actionRedo.setObjectName("actionRedo")
        self.actionTransmissions_dock = QtWidgets.QAction(MainWindow)
        self.actionTransmissions_dock.setCheckable(True)
        self.actionTransmissions_dock.setChecked(True)
        self.actionTransmissions_dock.setObjectName("actionTransmissions_dock")
        self.menuView.addAction(self.actionTransmissions_dock)
        self.menubar.addAction(self.menuView.menuAction())

        self.retranslateUi(MainWindow)
        self.sliderDotSize.valueChanged['int'].connect(self.label_4.setNum)
        self.actionTransmissions_dock.toggled['bool'].connect(self.dockWidget.setVisible)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)
        MainWindow.setTabOrder(self.btnModeView, self.btnModeDrag)
        MainWindow.setTabOrder(self.btnModeDrag, self.btnModeAddPeaks)
        MainWindow.setTabOrder(self.btnModeAddPeaks, self.btnModeAddBases)
        MainWindow.setTabOrder(self.btnModeAddBases, self.btnModeDelete)
        MainWindow.setTabOrder(self.btnModeDelete, self.sliderDotSize)
        MainWindow.setTabOrder(self.sliderDotSize, self.btnSetPeaksAtRelativeMaxima)
        MainWindow.setTabOrder(self.btnSetPeaksAtRelativeMaxima, self.btnSaveCurve)
        MainWindow.setTabOrder(self.btnSaveCurve, self.btnDisconnectFromFlowchart)
        MainWindow.setTabOrder(self.btnDisconnectFromFlowchart, self.lineEditSampleID)
        MainWindow.setTabOrder(self.lineEditSampleID, self.graphicsView)
        MainWindow.setTabOrder(self.graphicsView, self.listwIndices)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.label.setText(_translate("MainWindow", "Mode"))
        self.btnModeView.setText(_translate("MainWindow", "View"))
        self.btnModeDrag.setText(_translate("MainWindow", "Drag"))
        self.btnModeAddPeaks.setText(_translate("MainWindow", "Add Peaks"))
        self.btnModeAddBases.setText(_translate("MainWindow", "Add bases"))
        self.btnModeDelete.setText(_translate("MainWindow", "Delete"))
        self.label_3.setText(_translate("MainWindow", "Dot Size:"))
        self.label_4.setText(_translate("MainWindow", "15"))
        self.btnSetPeaksAtRelativeMaxima.setText(_translate("MainWindow", "Set peaks at\n"
"relative maxima"))
        self.btnSaveCurve.setText(_translate("MainWindow", "Save Curve"))
        self.btnClearCurve.setText(_translate("MainWindow", "Clear Curve"))
        self.btnDisconnectFromFlowchart.setText(_translate("MainWindow", "Disconnect from flowchart"))
        self.btnSendToFlowchart.setText(_translate("MainWindow", "Send all curves to flowchart"))
        self.pushButtonOpenInViewer.setText(_translate("MainWindow", "Open in Viewer"))
        self.label_2.setText(_translate("MainWindow", "SampleID:"))
        self.menuView.setTitle(_translate("MainWindow", "&View"))
        self.actionUndo.setText(_translate("MainWindow", "&Undo"))
        self.actionRedo.setText(_translate("MainWindow", "&Redo"))
        self.actionTransmissions_dock.setText(_translate("MainWindow", "&Transmissions dock"))

from ....pyqtgraphCore import PlotWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mesfile_io_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(560, 335)
        DockWidget.setFloating(True)
        DockWidget.setFeatures(QtWidgets.QDockWidget.AllDockWidgetFeatures)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout = QtWidgets.QGridLayout(self.dockWidgetContents)
        self.gridLayout.setObjectName("gridLayout")
        self.listwMesfile = QtWidgets.QListWidget(self.dockWidgetContents)
        self.listwMesfile.setEnabled(False)
        self.listwMesfile.setObjectName("listwMesfile")
        self.gridLayout.addWidget(self.listwMesfile, 2, 0, 1, 4)
        self.mesfile_label = QtWidgets.QLabel(self.dockWidgetContents)
        self.mesfile_label.setObjectName("mesfile_label")
        self.gridLayout.addWidget(self.mesfile_label, 1, 0, 1, 2)
        self.btnOpenMesFile = QtWidgets.QPushButton(self.dockWidgetContents)
        self.btnOpenMesFile.setObjectName("btnOpenMesFile")
        self.gridLayout.addWidget(self.btnOpenMesFile, 0, 0, 1, 1)
        self.btnStimMapGUI = QtWidgets.QPushButton(self.dockWidgetContents)
        self.btnStimMapGUI.setEnabled(False)
        self.btnStimMapGUI.setObjectName("btnStimMapGUI")
        self.gridLayout.addWidget(self.btnStimMapGUI, 0, 1, 1, 1)
        spacerItem = QtWidgets.QSpacerItem(325, 23, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem, 0, 2, 1, 2)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        _translate = QtCore.QCoreApplication.translate
        DockWidget.setWindowTitle(_translate("DockWidget", "Mesfile I/O"))
        self.mesfile_label.setText(_translate("DockWidget", "MES file contents:"))
        self.btnOpenMesFile.setText(_translate("DockWidget", "Open mes file"))
        self.btnStimMapGUI.setText(_translate("DockWidget", "Stim Map GUI"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './add_to_project_dialog_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(311, 446)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.lineEditAnimalID = QtWidgets.QLineEdit(Form)
        self.lineEditAnimalID.setObjectName("lineEditAnimalID")
        self.verticalLayout.addWidget(self.lineEditAnimalID)
        self.lineEditTrialID = QtWidgets.QLineEdit(Form)
        self.lineEditTrialID.setObjectName("lineEditTrialID")
        self.verticalLayout.addWidget(self.lineEditTrialID)
        self.textBoxComments = QtWidgets.QPlainTextEdit(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.textBoxComments.sizePolicy().hasHeightForWidth())
        self.textBoxComments.setSizePolicy(sizePolicy)
        self.textBoxComments.setObjectName("textBoxComments")
        self.verticalLayout.addWidget(self.textBoxComments)
        self.radioButtonAddToDataFrame = QtWidgets.QRadioButton(Form)
        self.radioButtonAddToDataFrame.setChecked(True)
        self.radioButtonAddToDataFrame.setObjectName("radioButtonAddToDataFrame")
        self.verticalLayout.addWidget(self.radioButtonAddToDataFrame)
        self.radioButtonSaveChanges = QtWidgets.QRadioButton(Form)
        self.radioButtonSaveChanges.setObjectName("radioButtonSaveChanges")
        self.verticalLayout.addWidget(self.radioButtonSaveChanges)
        self.checkBoxSaveChanges = QtWidgets.QCheckBox(Form)
        self.checkBoxSaveChanges.setEnabled(False)
        self.checkBoxSaveChanges.setObjectName("checkBoxSaveChanges")
        self.verticalLayout.addWidget(self.checkBoxSaveChanges)
        self.checkBoxOverwriteImage = QtWidgets.QCheckBox(Form)
        self.checkBoxOverwriteImage.setEnabled(False)
        self.checkBoxOverwriteImage.setChecked(True)
        self.checkBoxOverwriteImage.setObjectName("checkBoxOverwriteImage")
        self.verticalLayout.addWidget(self.checkBoxOverwriteImage)
        self.btnProceed = QtWidgets.QPushButton(Form)
        self.btnProceed.setObjectName("btnProceed")
        self.verticalLayout.addWidget(self.btnProceed)

        self.retranslateUi(Form)
        self.radioButtonSaveChanges.toggled['bool'].connect(self.checkBoxSaveChanges.setEnabled)
        self.radioButtonSaveChanges.toggled['bool'].connect(self.checkBoxSaveChanges.setVisible)
        self.radioButtonSaveChanges.toggled['bool'].connect(self.checkBoxOverwriteImage.setEnabled)
        self.radioButtonSaveChanges.toggled['bool'].connect(self.checkBoxOverwriteImage.setVisible)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.lineEditAnimalID.setPlaceholderText(_translate("Form", "*Animal ID"))
        self.lineEditTrialID.setPlaceholderText(_translate("Form", "*Trial ID"))
        self.textBoxComments.setPlaceholderText(_translate("Form", "Comments"))
        self.radioButtonAddToDataFrame.setText(_translate("Form", "Add to dataframe"))
        self.radioButtonSaveChanges.setText(_translate("Form", "Save changes (overwrite)"))
        self.checkBoxSaveChanges.setText(_translate("Form", "I\'m sure!"))
        self.checkBoxOverwriteImage.setToolTip(_translate("Form", "If you have not changed the actual image sequence you can save time by selecting this option."))
        self.checkBoxOverwriteImage.setText(_translate("Form", "Overwrite image data"))
        self.btnProceed.setText(_translate("Form", "Proceed"))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file './caiman_importer_pytemplate.ui'
#
# Created by: PyQt5 UI code generator 5.9.2
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_DockWidget(object):
    def setupUi(self, DockWidget):
        DockWidget.setObjectName("DockWidget")
        DockWidget.resize(595, 154)
        DockWidget.setFloating(True)
        self.dockWidgetContents = QtWidgets.QWidget()
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.dockWidgetContents)
        self.verticalLayout.setObjectName("verticalLayout")
        self.label = QtWidgets.QLabel(self.dockWidgetContents)
        self.label.setObjectName("label")
        self.verticalLayout.addWidget(self.label)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.pushButton_select_file = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton_select_file.setObjectName("pushButton_select_file")
        self.horizontalLayout_2.addWidget(self.pushButton_select_file)
        self.label_file = QtWidgets.QLabel(self.dockWidgetContents)
        self.label_file.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.label_file.setObjectName("label_file")
        self.horizontalLayout_2.addWidget(self.label_file)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.pushButton_import = QtWidgets.QPushButton(self.dockWidgetContents)
        self.pushButton_import.setObjectName("pushButton_import")
        self.horizontalLayout_3.addWidget(self.pushButton_import)
        spacerItem1 = QtWidgets.QSpacerItem(37, 17, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem2)
        DockWidget.setWidget(self.dockWidgetContents)

        self.retranslateUi(DockWidget)
        QtCore.QMetaObject.connectSlotsByName(DockWidget)

    def retranslateUi(self, DockWidget):
        _translate = QtCore.QCoreApplication.translate
        DockWidget.setWindowTitle(_translate("DockWidget", "Cai&man HDF5 Importer"))
        self.label.setText(_translate("DockWidget", "Import an HDF5 results file produced by Caiman to place ROIs in the current work environment"))
        self.pushButton_select_file.setToolTip(_translate("DockWidget", "Choose a dir containing suite2p output data"))
        self.pushButton_select_file.setText(_translate("DockWidget", "select file"))
        self.label_file.setText(_translate("DockWidget", "<not selected>"))
        self.pushButton_import.setText(_translate("DockWidget", "Import"))

